@@ -1,7 +1,9 @@
 from typing import Generic, TypeVar
 
+from pydantic.generics import GenericModel
+
 T = TypeVar("T")  # Declare type variable
 
 
-class IResponse(Generic[T]):
+class IResponse(GenericModel, Generic[T]):
     pass
