@@ -1,10 +1,12 @@
 import base64
-import dataclasses
 import io
-import logging
 import json as jsonlib
+import logging
 from typing import Any, Tuple, Union
 
+from pydantic import BaseModel
+
+from steamship.base.configuration import CamelModel
 from steamship.base.error import SteamshipError
 from steamship.base.mime_types import ContentEncodings, MimeTypes
 
@@ -12,30 +14,30 @@ from steamship.base.mime_types import ContentEncodings, MimeTypes
 def guess_mime(obj: Any, provided_mime: str = None) -> str:
     if provided_mime is not None:
         return provided_mime
-    if type(obj) in [str, int, float, bool]:
+    if isinstance(obj, (str, int, float, bool)):
         return MimeTypes.TXT
     return MimeTypes.BINARY
 
 
 def to_b64(obj: Any) -> str:
     ret_bytes = obj
-    if type(obj) == bytes:
+    if isinstance(obj, bytes):
         ret_bytes = obj
-    elif type(obj) == str:
+    elif isinstance(obj, str):
         ret_bytes = ret_bytes.encode("utf-8")
     else:
         ret_bytes = str(obj).encode("utf-8")
     return base64.b64encode(ret_bytes).decode("utf-8")
 
 
-def flexi_create(
-        base64string: str = None,
-        data: Any = None,
-        string: str = None,
-        json: Any = None,
-        bytes: Union[bytes, io.BytesIO] = None,
-        mime_type=None,
-        force_base64=False,
+def flexi_create(  # noqa: C901
+    base64string: str = None,
+    data: Any = None,
+    string: str = None,
+    json: Any = None,
+    _bytes: Union[bytes, io.BytesIO] = None,
+    mime_type=None,
+    force_base64=False,
 ) -> Tuple[Any, Union[None, str], Union[None, str]]:  # TODO (Enias): Review
     """
     It's convenient for some constructors to accept a variety of input types:
@@ -66,19 +68,22 @@ def flexi_create(
             ret_mime = mime_type or MimeTypes.JSON
 
             if hasattr(json, "to_dict"):
-                ret_dict = getattr(json, "to_dict")()
+                ret_dict = json.to_dict()
                 ret_data = ret_dict
-            elif dataclasses.is_dataclass(json):
-                ret_dict = dataclasses.asdict(json)
+            elif isinstance(json, CamelModel):
+                ret_dict = json.dict(by_alias=True)
+                ret_data = ret_dict
+            elif isinstance(json, BaseModel):
+                ret_dict = json.dict()
                 ret_data = ret_dict
             else:
                 ret_data = json
 
-        elif bytes is not None:
-            if isinstance(bytes, io.BytesIO):
-                bytes = bytes.getvalue()  # Turn it into regular bytes
+        elif _bytes is not None:
+            if isinstance(_bytes, io.BytesIO):
+                _bytes = _bytes.getvalue()  # Turn it into regular bytes
             ret_data, ret_mime = (
-                base64.b64encode(bytes).decode("utf-8"),
+                base64.b64encode(_bytes).decode("utf-8"),
                 mime_type or ret_mime or MimeTypes.BINARY,
             )
             is_b64 = True
@@ -90,7 +95,7 @@ def flexi_create(
             if is_b64 is True:
                 return ret_data, ret_mime, ContentEncodings.BASE64
             else:
-                if json is not None:
+                if json is not None or (data is not None and ret_mime == MimeTypes.JSON):
                     # If it was JSON, we need to dump the object first!
                     # Otherwise it will end up getting turned to the Python's object representation format
                     # which will result in invalid JSON
