@@ -1,18 +1,17 @@
-from dataclasses import dataclass
+from steamship.base.configuration import CamelModel
 
 
-class Request:
-    pass
+class Request(CamelModel):
+    class Config:
+        use_enum_values = True
 
 
-@dataclass
 class GetRequest(Request):
     id: str = None
     handle: str = None
     upsert: bool = None
 
 
-@dataclass
 class IdentifierRequest(Request):
     id: str = None
     handle: str = None
