@@ -2,7 +2,6 @@ from .app import App
 from .app_instance import AppInstance
 from .app_version import AppVersion
 from .block import Block
-from .corpus import Corpus
 from .embeddings import EmbeddingIndex
 from .file import File
 from .plugin import Plugin
@@ -10,3 +9,20 @@ from .plugin_instance import PluginInstance
 from .plugin_version import PluginVersion
 from .space import Space
 from .tags import DocTag, Tag, TagKind, TextTag
+
+__all__ = [
+    "App",
+    "AppInstance",
+    "AppVersion",
+    "Block",
+    "EmbeddingIndex",
+    "File",
+    "Plugin",
+    "PluginInstance",
+    "PluginVersion",
+    "Space",
+    "DocTag",
+    "Tag",
+    "TagKind",
+    "TextTag",
+]
