@@ -1,7 +1,6 @@
-from abc import ABC
-from typing import Any
+from abc import ABC, abstractmethod
 
-from steamship.base import Client
+from steamship.app import Response, post
 from steamship.plugin.inputs.file_import_plugin_input import FileImportPluginInput
 from steamship.plugin.outputs.raw_data_plugin_output import RawDataPluginOutput
 from steamship.plugin.service import PluginRequest, PluginService
@@ -16,8 +15,11 @@ from steamship.plugin.service import PluginRequest, PluginService
 # of this file.
 #
 class FileImporter(PluginService[FileImportPluginInput, RawDataPluginOutput], ABC):
-    @classmethod
-    def subclass_request_from_dict(
-        cls, d: Any, client: Client = None
-    ) -> PluginRequest[FileImportPluginInput]:
-        return FileImportPluginInput.from_dict(d, client=client)
+    @abstractmethod
+    def run(self, request: PluginRequest[FileImportPluginInput]) -> Response[RawDataPluginOutput]:
+        raise NotImplementedError()
+
+    @post("import")
+    def run_endpoint(self, **kwargs) -> Response[RawDataPluginOutput]:
+        """Exposes the File Importer's `run` operation to the Steamship Engine via the expected HTTP path POST /import"""
+        return self.run(PluginRequest[FileImportPluginInput](**kwargs))
